# -*- coding: utf-8 -*-

"""
@Project : hertz_packet 
@File    : log.py
@Date    : 2023/5/19 17:56:47
@Author  : zhchen
@Desc    : 
"""
import logging
import os
import sys
from datetime import datetime


class Logger:
    def __init__(self, log_path=None, file_name=None):
        self.logger = logging.getLogger(__name__)  # 创建日志记录器
        self.logger.setLevel(logging.INFO)  # 日志记录器的等级

        _format = logging.Formatter('%(asctime)s [%(filename)s] %(levelname)s: %(message)s',
                                    datefmt='%Y-%m-%d %H:%M:%S')

        file_name_date = datetime.now().strftime("%H_%M_%S")
        filename = file_name or f"{os.path.basename(sys.argv[0]).split('.')[0]}_{file_name_date}.log"
        path_name_date = datetime.now().strftime("%Y_%m_%d")
        log_path = log_path or f'./log/{path_name_date}'
        os.path.exists(log_path) or os.makedirs(log_path)
        file_handler = logging.FileHandler(f"{log_path}/{filename}", encoding='utf-8')
        file_handler.setLevel(logging.INFO)
        file_handler.setFormatter(_format)

        console = logging.StreamHandler()
        console.setLevel(logging.INFO)
        console.setFormatter(_format)

        self.logger.addHandler(file_handler)
        self.logger.addHandler(console)

    def get_logger(self):
        return self.logger



# -*- coding: utf-8 -*-

"""
@Project : hertz_packet 
@File    : log.py
@Date    : 2023/5/30 17:45:45
@Author  : zhchen
@Desc    : 
"""
from notice.log import Logger

logger = Logger().get_logger()
logger.info("hhh")



# -*- coding: utf-8 -*-


from distutils.core import setup

from setuptools import find_packages

with open("README.md", "r") as f:
    long_description = f.read()

setup(
    name='hertz_packet',  # 包名
    version='1.1.0',  # 版本号
    description='release Hertz',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='luke9012',
    author_email='luke781520097@163.com',
    url='https://github.com/luke1879012/hertz_packet',
    install_requires=[
        'requests~=2.27.1',
        'pymysql~=1.0.3',
    ],
    license='MIT',
    packages=find_packages(),
    platforms=["all"],
    python_requires='>=3.6',
    classifiers=[
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Natural Language :: Chinese (Simplified)',
        'Programming Language :: Python :: 3',
        "License :: OSI Approved :: MIT License",
    ],
)



# -*- coding: utf-8 -*-

"""
@Project : hertz_packet 
@File    : __init__.py
@Date    : 2023/5/12 10:31:05
@Author  : zhchen
@Desc    : 发送一些消息
"""
import json

import requests


def send_note(_k, _v, _memo: dict = None):
    """发送键值对到数据库，用于分析情况"""
    try:
        data = {"key": _k, "value": _v, }
        if _memo:
            data['memo'] = json.dumps(_memo)
        requests.post(
            "https://note-tempnote-edzsrbkyef.cn-hangzhou.fcapp.run",
            json=data)
    except Exception:
        pass
